import{r as e,t}from"./jsx-runtime-DAs1UGHr.js";import{l as n}from"./matchContext-DoIVbOYX.js";import{Mt as r,Nt as i,Ot as a,jt as o,kt as s}from"./preload-helper-D7v3KC5t.js";var c=e(n(),1),l=new Map([[`bold`,c.createElement(c.Fragment,null,c.createElement(`path`,{d:`M216,28H88A12,12,0,0,0,76,40V76H40A12,12,0,0,0,28,88V216a12,12,0,0,0,12,12H168a12,12,0,0,0,12-12V180h36a12,12,0,0,0,12-12V40A12,12,0,0,0,216,28ZM156,204H52V100H156Zm48-48H180V88a12,12,0,0,0-12-12H100V52H204Z`}))],[`duotone`,c.createElement(c.Fragment,null,c.createElement(`path`,{d:`M216,40V168H168V88H88V40Z`,opacity:`0.2`}),c.createElement(`path`,{d:`M216,32H88a8,8,0,0,0-8,8V80H40a8,8,0,0,0-8,8V216a8,8,0,0,0,8,8H168a8,8,0,0,0,8-8V176h40a8,8,0,0,0,8-8V40A8,8,0,0,0,216,32ZM160,208H48V96H160Zm48-48H176V88a8,8,0,0,0-8-8H96V48H208Z`}))],[`fill`,c.createElement(c.Fragment,null,c.createElement(`path`,{d:`M216,32H88a8,8,0,0,0-8,8V80H40a8,8,0,0,0-8,8V216a8,8,0,0,0,8,8H168a8,8,0,0,0,8-8V176h40a8,8,0,0,0,8-8V40A8,8,0,0,0,216,32Zm-8,128H176V88a8,8,0,0,0-8-8H96V48H208Z`}))],[`light`,c.createElement(c.Fragment,null,c.createElement(`path`,{d:`M216,34H88a6,6,0,0,0-6,6V82H40a6,6,0,0,0-6,6V216a6,6,0,0,0,6,6H168a6,6,0,0,0,6-6V174h42a6,6,0,0,0,6-6V40A6,6,0,0,0,216,34ZM162,210H46V94H162Zm48-48H174V88a6,6,0,0,0-6-6H94V46H210Z`}))],[`regular`,c.createElement(c.Fragment,null,c.createElement(`path`,{d:`M216,32H88a8,8,0,0,0-8,8V80H40a8,8,0,0,0-8,8V216a8,8,0,0,0,8,8H168a8,8,0,0,0,8-8V176h40a8,8,0,0,0,8-8V40A8,8,0,0,0,216,32ZM160,208H48V96H160Zm48-48H176V88a8,8,0,0,0-8-8H96V48H208Z`}))],[`thin`,c.createElement(c.Fragment,null,c.createElement(`path`,{d:`M216,36H88a4,4,0,0,0-4,4V84H40a4,4,0,0,0-4,4V216a4,4,0,0,0,4,4H168a4,4,0,0,0,4-4V172h44a4,4,0,0,0,4-4V40A4,4,0,0,0,216,36ZM164,212H44V92H164Zm48-48H172V88a4,4,0,0,0-4-4H92V44H212Z`}))]]),u=c.forwardRef((e,t)=>c.createElement(r,{ref:t,...e,weights:l}));u.displayName=`CopyIcon`;var d=t(),f=(e,t)=>Math.floor(Math.random()*(t-e+1)+e),p=(e,t)=>(Math.random()*(t-e)+e).toFixed(2),m=({minWidth:e=30,maxWidth:t=100,minDuration:n=1.3,maxDuration:r=1.7,minDelay:a=0,maxDelay:o=.5,className:s})=>{let{width:l,duration:u,delay:m}=(0,c.useMemo)(()=>({width:f(e,t),duration:p(n,r),delay:p(a,o)}),[e,t,n,r,a,o]),h={"--skeleton-width":`${l}%`,"--shimmer-duration":`${u}s`,"--shimmer-delay":`${m}s`};return(0,d.jsx)(`div`,{className:i(`skeleton-line`,s),style:h})},h={size:{sm:{classes:`text-sm h-10 gap-0.5`,description:`Compact breadcrumbs for dense UIs`},base:{classes:`text-base h-12 gap-1`,description:`Default breadcrumbs size`}}},g={size:`base`};function _({size:e=g.size}={}){return i(`group mr-4 hidden min-w-0 grow items-center sm:flex`,h.size[e].classes)}var v=({href:e,icon:t,children:n})=>(0,d.jsxs)(s(),{to:e,className:`flex min-w-0 items-center gap-1 text-kumo-subtle no-underline`,children:[!!t&&(0,d.jsx)(`span`,{className:`flex shrink-0 items-center`,children:t}),n]});function y({children:e,icon:t,loading:n}){return n?(0,d.jsxs)(`div`,{className:`flex w-[125px] min-w-0 items-center gap-1`,children:[t&&(0,d.jsx)(`span`,{className:`flex shrink-0 items-center`,children:t}),(0,d.jsx)(m,{})]}):(0,d.jsxs)(`div`,{className:`flex items-center gap-1 truncate font-medium`,"aria-current":`page`,children:[t&&(0,d.jsx)(`span`,{className:`flex shrink-0 items-center`,children:t}),e]})}function b(){return(0,d.jsx)(`span`,{className:`flex items-center text-kumo-inactive`,"aria-hidden":`true`,children:(0,d.jsx)(`svg`,{width:`24`,height:`24`,fill:`none`,viewBox:`0 0 24 24`,children:(0,d.jsx)(`path`,{stroke:`currentColor`,strokeLinecap:`round`,strokeLinejoin:`round`,strokeWidth:`1.5`,d:`M10.75 8.75L14.25 12L10.75 15.25`})})})}function x({text:e}){let[t,n]=(0,c.useState)(!1);return(0,c.useEffect)(()=>{if(!t)return;let e=setTimeout(()=>n(!1),2e3);return()=>clearTimeout(e)},[t]),(0,d.jsx)(a,{variant:`ghost`,shape:`square`,size:`sm`,className:`opacity-0 transition-[opacity] group-hover:opacity-100`,onClick:async()=>{if(e)try{await navigator.clipboard.writeText(e),n(!0)}catch(e){console.error(`Failed to copy deeplink:`,e)}},title:`Click to copy`,"aria-label":`Copy`,children:t?(0,d.jsx)(o,{weight:`bold`,className:`text-kumo-success`}):(0,d.jsx)(u,{weight:`regular`})})}function S({children:e,size:t=`base`,className:n}){return(0,d.jsx)(`nav`,{className:i(_({size:t}),n),"aria-label":`breadcrumb`,children:e})}S.Link=v,S.Current=y,S.Separator=b,S.Clipboard=x;function C({children:e,icon:t,items:n,title:r}){return(0,d.jsxs)(`div`,{className:`box-border flex min-h-16.75 shrink-0 items-center gap-2 border-b border-kumo-fill bg-kumo-elevated px-6 py-4 text-sm`,children:[(0,d.jsxs)(S,{children:[(0,d.jsx)(S.Current,{icon:(0,d.jsx)(t,{className:`h-4 w-4`}),children:r}),n.map((e,t)=>(0,d.jsxs)(c.Fragment,{children:[(0,d.jsx)(S.Separator,{}),e]},t))]}),e]})}export{S as n,u as r,C as t};