import{r as e,t}from"./jsx-runtime-DAs1UGHr.js";import{l as n}from"./matchContext-DoIVbOYX.js";import{Nt as r}from"./preload-helper-D7v3KC5t.js";var i=t(),a=e(n(),1),o={variant:{heading1:{classes:`text-3xl font-semibold`,description:`Large heading for page titles`},heading2:{classes:`text-2xl font-semibold`,description:`Medium heading for section titles`},heading3:{classes:`text-lg font-semibold`,description:`Small heading for subsections`},body:{classes:`text-kumo-default`,description:`Default body text`},secondary:{classes:`text-kumo-subtle`,description:`Muted text for secondary information`},success:{classes:`text-kumo-link`,description:`Success state text`},error:{classes:`text-kumo-danger`,description:`Error state text`},mono:{classes:`font-mono`,description:`Monospace text for code`},"mono-secondary":{classes:`font-mono text-kumo-subtle`,description:`Muted monospace text`}},size:{xs:{classes:`text-xs`,description:`Extra small text`},sm:{classes:`text-sm`,description:`Small text`},base:{classes:`text-base`,description:`Default text size`},lg:{classes:`text-lg`,description:`Large text`}}};function s({variant:e=`body`,bold:t=!1,size:n=`base`,children:s,DANGEROUS_className:c,DANGEROUS_style:l,as:u,...d},f){let p=[`body`,`secondary`,`success`,`error`].includes(e),m=[`mono`,`mono-secondary`].includes(e);return(0,i.jsx)((0,a.useMemo)(()=>u||(e===`heading1`?`h1`:e===`heading2`?`h2`:e===`heading3`?`h3`:[`mono`,`mono-secondary`].includes(e)?`span`:`p`),[e,u]),{ref:f,className:r(`text-kumo-default`,o.variant[e].classes,p?o.size[n].classes:``,p&&t?`font-medium`:``,m&&(n===`lg`?o.size.base.classes:o.size.sm.classes),c),style:l,...d,children:s})}var c=(0,a.forwardRef)(s);export{c as t};